% This code accompanies the paper:
%
% "Elastic Net Constraints for Shape Matching"
% E.Rodola, A.Torsello, T.Harada, Y.Kuniyoshi, and D.Cremers
% 2013 IEEE International Conference on Computer Vision (ICCV 2013)
%
% Please cite the paper above if you use this code.
%
% Emanuele Rodola
% The University of Tokyo, 2012
% TU Munich, 2013
% <rodola@in.tum.de>

%% Projection onto elastic net ball with given radius and convexity

v = rand(1e5,1);
alpha = rand();
radius = 7;

norm_before = (1-alpha)*sum(abs(v)) + alpha*(v'*v);

if norm_before <= radius
    fprintf('The given vector is already inside the ball. Norm: %.4f\n', norm_before);
end

tic;
[x,iters] = proj_enet(v,alpha,radius);
elapsed = toc;

norm_after = (1-alpha)*sum(abs(x)) + alpha*(x'*x);

fprintf('Elapsed: %.8f sec\nE-net norm after projection: %.10f\n', elapsed, norm_after);
